Opbeat

.. .. image:: https://secure.travis-ci.org/dcramer/opbeat.png?branch=master
..    :target: http://travis-ci.org/dcramer/opbeat

This is a Python client for `Opbeat <http://opbeat.com/>`_. It provides 
full out-of-the-box support for many of the popular frameworks, including
Django, and Flask. Opbeat also includes drop-in support for any WSGI-compatible
web application.

Your application doesn't live on the web? No problem! Opbeat is easy to use in
any Python application.



Resources
---------

* `Documentation <https://www.opbeat.com/docs>`_
* `Bug Tracker <http://github.com/opbeat/opbeat/issues>`_
* `Code <http://github.com/opbeat/opbeat>`_
.. * `Mailing List <https://groups.google.com/group/getsentry>`_
.. * `IRC <irc://irc.freenode.net/sentry>`_  (irc.freenode.net, #sentry)
